@@ -8,7 +8,7 @@ import contextlib
 import matplotlib.pyplot as plt
 import numpy as np
 import pytest
-from hypothesis import given, settings
+from hypothesis import HealthCheck, given, settings
 from matplotlib.figure import Figure
 from packaging import version
 
@@ -314,6 +314,38 @@ def test_rotation_matrix_crota(aia171_test_map):
                                          [3.38820761e-04, 9.99999943e-01]]))
 
 
+_PC_KEYWORDS = ['PC1_1', 'PC1_2', 'PC2_1', 'PC2_2']
+_CD_KEYWORDS = ['CD1_1', 'CD1_2', 'CD2_1', 'CD2_2']
+
+
+@pytest.mark.parametrize('key', ['PC', 'CD'])
+@pytest.mark.parametrize('i', [1, 2])
+@pytest.mark.parametrize('j', [1, 2])
+def test_rotation_matrix_defaults(generic_map, i, j, key):
+    # Check that missing rotation keywords are set to correct defaults
+    #
+    # Relevant bit of the FITS standard:
+    #
+    # > PCi_j – [floating point; defaults: 1.0 when i = j, 0.0 otherwise]
+    # > if any CDi_j keywords are present in the HDU, all other unspecified CDi_j keywords shall default to zero
+    for keyword in _PC_KEYWORDS + _CD_KEYWORDS:
+        if keyword in generic_map.meta:
+            del generic_map.meta[keyword]
+
+    keyword = f'{key}{i}_{j}'
+    # Arbitrary number
+    generic_map.meta[keyword] = 1.2
+    if key == 'CD':
+        expected = np.zeros((2, 2))
+        expected[i-1, j-1] = 0.12
+    elif key == 'PC':
+        expected = np.eye(2)
+        expected[i-1, j-1] = 1.2
+
+    rot_mat = generic_map.rotation_matrix
+    np.testing.assert_equal(rot_mat, expected)
+
+
 def test_rotation_matrix_cd_cdelt():
     data = np.ones([6, 6], dtype=np.float64)
     header = {
@@ -830,7 +862,12 @@ def test_superpixel_fractional_inputs(generic_map):
 
 
 @pytest.mark.parametrize('method', ['resample', 'superpixel'])
-@settings(max_examples=10, deadline=1000)
+@settings(
+    max_examples=10,
+    # Lots of draws can be discarded when checking matrix is non-singular
+    suppress_health_check=[HealthCheck.filter_too_much],
+    deadline=1000,
+)
 @given(pc=matrix_meta('pc'))
 def test_resample_rotated_map_pc(pc, method):
     smap = make_simple_map()
@@ -846,7 +883,12 @@ def test_resample_rotated_map_pc(pc, method):
 
 
 @pytest.mark.parametrize('method', ['resample', 'superpixel'])
-@settings(max_examples=10, deadline=1000)
+@settings(
+    max_examples=10,
+    # Lots of draws can be discarded when checking matrix is non-singular
+    suppress_health_check=[HealthCheck.filter_too_much],
+    deadline=1000,
+)
 @given(cd=matrix_meta('cd'))
 def test_resample_rotated_map_cd(cd, method):
     smap = make_simple_map()
@@ -1277,6 +1319,8 @@ def test_contour(simple_map):
     assert contour.obstime == simple_map.date
     assert u.allclose(contour.Tx, [0, -1, 0, 1, 0] * u.arcsec, atol=1e-10 * u.arcsec)
     assert u.allclose(contour.Ty, [0.5, 0, -0.5, 0, 0.5] * u.arcsec, atol=1e-10 * u.arcsec)
+    with pytest.raises(ValueError, match='level must be a single scalar value'):
+        simple_map.contour([1.5, 2.5])
 
 
 def test_contour_units(simple_map):
